# TODO

For each algorithm, a tutorial (PDF file and/or ipython notebook) should be add...

## Optimisation

- [ ] Add the most famous metaheuristics
    - [ ] Evolutionnary Algorithms (SAES, CMAES, ...)
    - [ ] EDA
    - [ ] Simulated annealing
    - [ ] Tabou search
    - [ ] Stochastic gradient descent
    - [ ] Genetic algorithms
    - [ ] Cross entropy method
    - [ ] Ant colony optimization
    - [ ] Particle swarm optimization
    - [ ] Newton, ...
- [ ] Add constrained optimization algorithms
    - [ ] Linear programming: simplex, ...
    - [ ] Cutting plane methods
    - [ ] CSP
- [ ] Add multi-objectives optimization algorithms
- [ ] Gradient descente
    - [ ] Optimize Epsilon (adaptation du pas de descente) : cf. wikipedia
    - [ ] Plot/display the gradient (?)
- [ ] Add new fitness fonctions
    - [ ] Add wikipedia's [test functions for optimization](http://en.wikipedia.org/wiki/Test_functions_for_optimization) (x18) and add a picture for each
    - [ ] See the BBOB benchmark
- [ ] Cutting plane
    - [ ] clean...
    - [ ] ajouter les bornes du PL dans le PL
    - [ ] traiter la coupe initiale à part dans le PL
    - [ ] benchmark

## Machine Learning Framework

- [ ] ID3
- [ ] Perceptron
- [ ] Adaline
- [ ] Multi-layered neural network
- [ ] SVM

## Multi-stage Optimization, MDP and Reinforcement Learning Framework

- [ ] Value Iteration
- [ ] Policy Iteration
- [ ] Qlearning
- [ ] SARSA

## Game Framework

- [ ] Minimax
- [ ] Alpha-Beta
- [ ] MCTS

## Graph Search

- [ ] A*
